@@ -18,8 +18,7 @@ sub store($c) {
     $c->openapi->valid_input or return;
     my $in = $c->validation->output;
     my $id = $c->domove->add($in);
-    $c->res->headers->location(
-                          $c->url_for("api.show_domove", id => $id)->to_string);
+    $c->res->headers->location($c->url_for("api.show_domove", id => $id)->to_string);
     return $c->render(openapi => '', status => 201);
   }
 
@@ -66,16 +65,14 @@ sub show($c) {
   my $id  = $c->param('id');
   my $row = $c->domove->find($id);
   if ($c->current_route =~ /^api\./) {    #invoked via OpenAPI
-    return
-      $c->render(
-         openapi => {errors => [{path => $c->url_for, message => 'Not Found'}]},
-         status  => 404)
-      unless $row;
+    return $c->render(
+      openapi => {errors => [{path => $c->url_for, message => 'Not Found'}]},
+      status  => 404
+    ) unless $row;
     return $c->render(openapi => $row);
   }
-  return $c->render(text => $c->res->default_message(404), status => 404)
-    unless $row;
-  return $c->render(dom => $row);
+  return $c->render(text => $c->res->default_message(404), status => 404) unless $row;
+  return $c->render(dom  => $row);
 }
 
 # GET /domove
@@ -97,8 +94,9 @@ sub remove($c) {
     my $input = $c->validation->output;
     my $row   = $c->domove->find($input->{id});
     $c->render(
-         openapi => {errors => [{path => $c->url_for, message => 'Not Found'}]},
-         status  => 404)
+      openapi => {errors => [{path => $c->url_for, message => 'Not Found'}]},
+      status  => 404
+      )
       && return
       unless $row;
     $c->domove->remove($input->{id});
