@@ -42,26 +42,26 @@ sub send_mail_by_net_smtp ($message, $to_user, $app) {
 my sub _mail_message ($t, $from_user, $to_user, $app, $domain) {
   state $mt        = Mojo::Template->new(vars => 1);
   state $mail_body = 'task/send_onboarding_email.txt.ep';
-  state $mail_tmpl = c(@{$app->renderer->paths})
-    ->first(sub { -f path($_, $mail_body)->to_string; }) . "/$mail_body";
+  state $mail_tmpl
+    = c(@{$app->renderer->paths})->first(sub { -f path($_, $mail_body)->to_string; })
+    . "/$mail_body";
 
   #This token will be compared with the provided by the new user data
   #(first_name and last_name).
   my $token
     = sha1_sum($t
-         . encode('UTF-8' => $from_user->{first_name} . $from_user->{last_name})
-         . $from_user->{id}
-         . $to_user->{id});
+      . encode('UTF-8' => $from_user->{first_name} . $from_user->{last_name})
+      . $from_user->{id}
+      . $to_user->{id});
   my $body = $mt->render_file(
-                              $mail_tmpl => {
-                                    time            => $t,
-                                    from_user       => $from_user,
-                                    to_user         => $to_user,
-                                    domain          => $domain,
-                                    token           => $token,
-                                    token_valid_for => $CONF->{token_valid_for},
-                              }
-                             );
+    $mail_tmpl => {
+      time            => $t,
+      from_user       => $from_user,
+      to_user         => $to_user,
+      domain          => $domain,
+      token           => $token,
+      token_valid_for => $CONF->{token_valid_for},
+    });
   my $subject
     = 'Потребителска сметка за '
     . $to_user->{first_name} . ' '
@@ -90,24 +90,24 @@ MAIL
 # user with a first time login link.
 my sub _mail_first_login ($job, $from_user, $to_user, $domain) {
   state $app = $job->app;
-  my $t     = time;
-  my $token = _mail_message($t, $from_user, $to_user, $app, $domain);
+  my $t         = time;
+  my $token     = _mail_message($t, $from_user, $to_user, $app, $domain);
   my $token_row = {
-                   from_uid   => $from_user->{id},
-                   to_uid     => $to_user->{id},
-                   token      => $token,
-                   start_date => $t,
-                   stop_date  => $t + $CONF->{token_valid_for}
-                  };
+    from_uid   => $from_user->{id},
+    to_uid     => $to_user->{id},
+    token      => $token,
+    start_date => $t,
+    stop_date  => $t + $CONF->{token_valid_for}};
   $app->dbx->db->insert('first_login' => $token_row);
-  $app->minion->enqueue(delete_first_login => [$to_user->{id}, $token] =>
-                        {delay => $CONF->{token_valid_for}});
-  $job->finish(  'Писмото за първo влизане в '
-               . $domain
-               . ' до '
-               . $to_user->{first_name} . ' '
-               . $to_user->{last_name}
-               . ' бе успешно изпратено!');
+  $app->minion->enqueue(
+    delete_first_login => [$to_user->{id}, $token] => {delay => $CONF->{token_valid_for}}
+  );
+  $job->finish('Писмото за първo влизане в '
+      . $domain
+      . ' до '
+      . $to_user->{first_name} . ' '
+      . $to_user->{last_name}
+      . ' бе успешно изпратено!');
 };    ## Perl::Critic bug needs ";" at the end of private subs
 
 # Job implementation for deleting the token record for first login of the newly
@@ -131,19 +131,15 @@ sub register ($self, $app, $conf) {
 sub validate_conf ($self, $conf) {
   my $ME = 'Mojo::Exception';
   $ME->throw(
-    q|Parameters to Net::SMT->new ('Net::SMTP'->{new}) must be a reference to hash.|
-    )
+    q|Parameters to Net::SMT->new ('Net::SMTP'->{new}) must be a reference to hash.|)
     unless ref($conf->{'Net::SMTP'}{new}) eq 'HASH';
-  $ME->throw(
-       q|Username ('Net::SMTP'->{auth}[0]) is a mandatory configuration value.|)
+  $ME->throw(q|Username ('Net::SMTP'->{auth}[0]) is a mandatory configuration value.|)
     unless $conf->{'Net::SMTP'}{auth} && $conf->{'Net::SMTP'}{auth}[0];
-  $ME->throw(
-       q|Password ('Net::SMTP'->{auth}[1]) is a mandatory configuration value.|)
+  $ME->throw(q|Password ('Net::SMTP'->{auth}[1]) is a mandatory configuration value.|)
     unless $conf->{'Net::SMTP'}{auth} && $conf->{'Net::SMTP'}{auth}[1];
-  $ME->throw(  q|Mail ('Net::SMTP'->{mail}) is a mandatory configuration value.|
-             . 'It must be a valid email')
-    unless $conf->{'Net::SMTP'}{mail}
-    =~ /^[\w\-\+\.]{1,154}\@[\w\-\+\.]{1,100}$/x;
+  $ME->throw(q|Mail ('Net::SMTP'->{mail}) is a mandatory configuration value.|
+      . 'It must be a valid email')
+    unless $conf->{'Net::SMTP'}{mail} =~ /^[\w\-\+\.]{1,154}\@[\w\-\+\.]{1,100}$/x;
   return $conf;
 }
 
